<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten.</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sailcut</source>
        <translation type="obsolete">Sailcut</translation>
    </message>
    <message>
        <source>Sail corners coordinates</source>
        <translation>Eckpunktkoordinaten des Segels</translation>
    </message>
    <message>
        <source>tack</source>
        <translation>Segelhals</translation>
    </message>
    <message>
        <source>clew</source>
        <translation>Schothorn</translation>
    </message>
    <message>
        <source>head</source>
        <translation>Kopf</translation>
    </message>
    <message>
        <source>peak</source>
        <translation>Nock</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation>IRC - Breite</translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Definition des Segels</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Segelabmessungen</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Position des Bogens</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Länge des Vorlieks</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Länge des Unterlieks</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Länge des Achterlieks</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Länge der Gaffel</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Achterliek-Bogen</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel-Bogen</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Unterliek-Bogen</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>°</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Geometrie der Takelage</translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Segelhalshöhe</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Abstand zwischen Segelhals und Vorsteven</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fock</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Bootslänge LüA</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Neigung der Mastspur</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>Material</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Nahtbreite</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Bahnbreite</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Schnitt</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Gehrungsschnitt</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Kreuzschnitt</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Twist-Foot Schnitt</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Horizontalschnitt</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Anzahl der Segmente</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Anzahl der Radialkeile</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Radialschnitt</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Vertikalschnitt</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Obere Segeltiefe</translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Mittlere Segeltiefe</translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Untere Segeltiefe</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Verwindungswinkel</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Achterlieksaum</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Andere Säume</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Winkel der Segelbahn</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Segelfläche</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonale</translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Berechnen</translation>
    </message>
    <message>
        <source>Sail ID </source>
        <translation>Segel ID</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Anzahl der Radialkeile beginnend am Kopf und endend am Segelhals</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation>Öffnungswinkel</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Tragfläche</translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation>Segelnummer</translation>
    </message>
    <message>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Sailcut CAD Handbuch</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>&amp;TXT Segel</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>&amp;XML Segel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>Ö&amp;ffnen</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Be&amp;enden</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>&amp;Abmessungen</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>&amp;Form</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>&amp;Verstärkungen</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>&amp;Rigg</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>About Sailcut</source>
        <translation>über Sailcut</translation>
    </message>
    <message>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>über &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut</source>
        <translation>über &amp;Sailcut</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>zuletzt geöffnete P&amp;rojekte</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>E&amp;xport 3D-Segel</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>&amp;Carlson Plotter</translation>
    </message>
    <message>
        <source>Sailcut &amp;Handbook</source>
        <translation>Sailcut-&amp;Handbuch</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>schattierte Ansicht</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation>Ansicht als Drahtmodell</translation>
    </message>
    <message>
        <source>development</source>
        <translation>Entwicklung</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation>neu erstelltes Segel</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>geladen &apos;%1&apos;</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>Fehler beim Laden von &apos;%1&apos; </translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>gespeichert &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>Fehler beim Drucken der Entwicklungsansicht</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Fehler beim drucken der Zeichnung</translation>
    </message>
    <message>
        <source>data</source>
        <translation>Daten</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>Zeichnung</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>Dr&amp;ucken</translation>
    </message>
    <message>
        <source>Sailcut data sheet</source>
        <translation>Sailcut - Datenblatt</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Segeltyp</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fock</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Segelschnitt</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Kreuzschnitt</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Horizontalschnitt</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Radialschnitt</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Twist-Foot Schnitt</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Vertikalschnitt</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Gehrungsschnitt</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation> Segmente,   </translation>
    </message>
    <message>
        <source>Rig </source>
        <translation>Rigg </translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Bootslänge LüA</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Segelhalsposition X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Segelhalshöhe Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Segelabmessungen</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Länge des Vorlieks</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Länge der Gaffel</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Länge des Unterlieks</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Länge des Achterlieks</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation></translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel-Bogen</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Achterliek-Bogen</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Unterliek-Bogen</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Position des Vorliekbogens</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Position des Gaffelbogens</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Position des Achterliekbogens</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Position des Unterliekbogens</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Eigenschaften des Segels</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Verwindungswinkel</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Winkel der Segelbahn</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Bahnennähte und Säume</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Bahnbreite</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Nahtbreite</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Breite des Achterlieksaumes</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation>andere Saumbreiten</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Vorliegsfaktor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Tiefe</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Achterlieksfaktor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Oberes Profil</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Mittleres Profil bei Höhe h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Unteres Profil</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Neigung der Mastspur</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation>Radialkeile im Kopfabschnitt </translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Tragfläche</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation>Radialkeile beginnend am Kopf und endend am Segelhals.</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>°</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Export &amp;Entwicklung</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation>ins &amp;Hand-Plotterformat </translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Senkrechte Teilung</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Oberes Profil</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Mittleres Profil</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Unteres Profil</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation>Rigg </translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>&amp;Definition des Segels</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>3D &amp;Segel</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>neues Segel &amp;hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>Ö&amp;ffnen</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>zuletzt geöffnete P&amp;rojekte</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Be&amp;enden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Information des Segels</translation>
    </message>
    <message>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>name</source>
        <translation>Bezeichnung</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>neu laden</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Dieses System hat keine OpenGL Unterstützung.</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Anzeigeparameter</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>vertikal</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>horizontal</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Darstellung</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>Ansicht zurücksetzen</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Segelzeichen</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Einzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Auszoomen</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>°</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Luff shape</source>
        <translation>Vorliekform</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Tiefe</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Achterliekform</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
</context>
</TS>
